.. Tunir documentation master file, created by
   sphinx-quickstart on Thu Jan 15 22:45:09 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Tunir
================

Tunir is a simple CI system. The goal is to have a system which is
simple to setup, and easy to maintain.

Contents:

.. toctree::
   :maxdepth: 2

   why
   installation
   usage


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

